@@ -1,4 +1,4 @@
-from djraphql.util.django_models import get_pk_fields_for_model
+from djraphql.django_models import get_pk_fields_for_model
 from ..mappings import Types
 from ...abstract_type_builder import CacheableTypeBuilder
 
