@@ -4,7 +4,7 @@ from graphene import Field, List, ObjectType
 from ...resolvers.field import build_field_resolver
 from ...resolvers.list import build_list_resolver
 from ...util.arguments import create_query_arguments
-from .....util.django_models import get_field_by_name, get_target_field
+from .....django_models import get_field_by_name, get_target_field
 
 
 class BasicType(CacheableTypeBuilder, AbstractTypeBuilder):
